mbrs: A library for MBR decoding
================================

*mbrs* is a library for minimum Bayes risk (MBR) decoding, implementing various methods and metrics.

.. grid:: 2
   :margin: 3
   :padding: 2
   :gutter: 3 3 3 3

   .. grid-item-card:: :material-regular:`rocket_launch;2em` Getting started
      :class-card: sd-border-0

      - :doc:`installation`
      - :doc:`api_python`
      - :doc:`cli`
      - :doc:`yaml_config`
      - :doc:`tips`

   .. grid-item-card:: :material-regular:`list_alt;2em` Implementation lists
      :class-card: sd-border-0

      - :doc:`list_metrics`
      - :doc:`list_decoders`
      - :doc:`list_selectors`

   .. grid-item-card:: :material-regular:`extension;2em` Extending mbrs
      :class-card: sd-border-0

      - :doc:`design`
      - :doc:`custom_metric`
      - :doc:`custom_decoder`
      - :doc:`plugin`
      - :doc:`timer`

   .. grid-item-card:: :material-regular:`library_books;2em` References
      :class-card: sd-border-0

      - :doc:`cli_help`
      - :doc:`source/mbrs`

.. toctree::
   :maxdepth: 1
   :caption: Getting started:
   :hidden:

   installation
   api_python
   cli
   yaml_config
   tips

.. toctree::
   :maxdepth: 1
   :caption: Support lists:
   :hidden:

   list_metrics
   list_decoders
   list_selectors

.. toctree::
   :maxdepth: 1
   :caption: Extending mbrs:
   :hidden:

   design
   custom_metric
   custom_decoder
   plugin
   timer

.. toctree::
   :maxdepth: 1
   :caption: References:
   :hidden:

   cli_help
   source/mbrs
